# PostScheduledEventRequestParametersValueValueType

The type of the value.

## Enum

* `STRING` (value: `'STRING'`)

* `BYTE` (value: `'BYTE'`)

* `SHORT` (value: `'SHORT'`)

* `CHARACTER` (value: `'CHARACTER'`)

* `INTEGER` (value: `'INTEGER'`)

* `LONG` (value: `'LONG'`)

* `FLOAT` (value: `'FLOAT'`)

* `DOUBLE` (value: `'DOUBLE'`)

* `BOOLEAN` (value: `'BOOLEAN'`)

* `BIG_INTEGER` (value: `'BIG_INTEGER'`)

* `BIG_DECIMAL` (value: `'BIG_DECIMAL'`)

* `LOCAL_DATE` (value: `'LOCAL_DATE'`)

* `LOCAL_DATE_TIME` (value: `'LOCAL_DATE_TIME'`)

* `TIMESTAMP` (value: `'TIMESTAMP'`)

* `BYTE_ARRAY` (value: `'BYTE_ARRAY'`)

* `SHORT_ARRAY` (value: `'SHORT_ARRAY'`)

* `CHARACTER_ARRAY` (value: `'CHARACTER_ARRAY'`)

* `INTEGER_ARRAY` (value: `'INTEGER_ARRAY'`)

* `FLOAT_ARRAY` (value: `'FLOAT_ARRAY'`)

* `DOUBLE_ARRAY` (value: `'DOUBLE_ARRAY'`)

* `BOOLEAN_ARRAY` (value: `'BOOLEAN_ARRAY'`)

* `STRING_ARRAY` (value: `'STRING_ARRAY'`)

* `BIG_INTEGER_ARRAY` (value: `'BIG_INTEGER_ARRAY'`)

* `BIG_DECIMAL_ARRAY` (value: `'BIG_DECIMAL_ARRAY'`)

* `LOCAL_DATE_ARRAY` (value: `'LOCAL_DATE_ARRAY'`)

* `LOCAL_DATE_TIME_ARRAY` (value: `'LOCAL_DATE_TIME_ARRAY'`)

* `TIMESTAMP_ARRAY` (value: `'TIMESTAMP_ARRAY'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


